@@ -139,22 +139,9 @@ class ModelTorchAdapter(Model):
             self.summarywriter = None
         self.cleanCsv()
 
-        metricDefinitions = {
-            # init value, useAsBest, biggerIsBetter
-            "AUC": [0.5, False, True],
-            "AP": [0.0, True, True],
-            "accuracy": [0.0, False, True],
-            "kappa": [-1, True, True],
-            "CSI": [0, True, True],
-            "loss": [np.inf, True, False],
-            "meanSquared": [np.inf, True, False],
-            "SNR": [np.inf, False, False],
-            "confusion": [np.inf, False, False],
-            "auroc": [0.0, False, True],
-            "auprc": [0.0, True, True],
-            "eventCountDiff": [np.inf, False, False],
-            "positiveErrorRatio": [np.inf, True, False],
-        }
+        metrics = self.validationMetrics
+        scorer = ScorerTorch(self.numClasses)
+        metricDefinitions = {m: scorer.getMetricDefinition(m) for m in metrics}
 
         model = self.model
         globalBestMetric = self.validationMetrics[0]
