@@ -17,7 +17,9 @@ class Scorer:
             "AUC": [0.5, False, True],
             "AP": [0.0, True, True],
             "accuracy": [0.0, False, True],
+            "acc": [0.0, False, True],
             "kappa": [-1, True, True],
+            "f1": [-1, True, True],
             "CSI": [0, True, True],
             "loss": [np.inf, True, False],
             "meanSquared": [np.inf, True, False],
@@ -155,6 +157,9 @@ class Scorer:
         if metricName in ["kappa", "accuracy"]:  # recalcuate from confusion
             self.combineMetric("confusion")
             self.scoreMetric("kappa", None, None)
+        if metricName == "f1":  # recalcuate from confusion
+            self.combineMetric("confusion")
+            self.scoreMetric("f1", None, None)
         elif metricName == "confusion":  # combine all confusion
             result = np.array(
                 [self.recordResult[id]["confusion"] for id in self.recordResult if len(self.recordResult[id]["confusion"]) > 0]
@@ -316,6 +321,10 @@ class Scorer:
             k, acc = self.calculateKappaAccFromConfusion(confusion)
             self.results["accuracy"] = acc
             self.results["kappa"] = k
+        elif metricName in ["f1"]:
+            (tn, fn), (fp, tp) = self.scoreMetric("confusion", truth, prediction)
+            f1 = tp / (tp + 0.5 * (fp + fn))
+            self.results["f1"] = f1
         elif metricName == "confusion":
             prediction = self.flattenPrediction(prediction, threshold=self.threshold)
             result = confusion_matrix(
@@ -396,7 +405,7 @@ class Scorer:
             self.results[metricName] = np.where(sd == 0, 0, m / sd)
         elif metricName == "fm":  # Fowlkes–Mallows index
             confusion = self.scoreMetric("confusion", truth, prediction)
-            (tn, fp), (fn, tp) = confusion
+            (tn, fn), (fp, tp) = confusion
 
             tp = confusion[-1][-1]
             tn = confusion[0][0]
